#include "mywindow.h"


MyWindow::MyWindow(QWidget *parent)
  : QWidget(parent)
{
  QGridLayout *grid = new QGridLayout;
  grid->addWidget(createFirstExclusiveGroup(), 0, 0);
  grid->addWidget(createSecondExclusiveGroup(), 1, 0);
  grid->addWidget(createNonExclusiveGroup(), 0, 1);
  grid->addWidget(createPushButtonGroup(), 1, 1);
  setLayout(grid);

  connect(list,SIGNAL(currentIndexChanged(int)), this, SLOT(changeItem(int)));
  connect(this,SIGNAL(itemChanged(int)), this, SLOT(setListItem(int)));
  connect(pushButton, SIGNAL(clicked()), this, SLOT(removeFirstItem()));

  setWindowTitle(tr("Group Boxes"));
  resize(480, 320);
}

void MyWindow::changeItem(int index) {
  
  cout << "new item selected : " << (index+1) << endl;

  emit itemChanged(index);
}

void MyWindow::setListItem(int index) {
  list->setCurrentIndex(index);
}

void MyWindow::removeFirstItem() {
  bool current = false;
  if (list->currentIndex() == 1) current = true;
  disconnect(list,SIGNAL(currentIndexChanged(int)), this, SLOT(changeItem(int)));
  list->removeItem(1);
  connect(list,SIGNAL(currentIndexChanged(int)), this, SLOT(changeItem(int)));
  if (current) {
    setListItem(2);
  }
}

QGroupBox *MyWindow::createFirstExclusiveGroup()
{
  QGroupBox *groupBox = new QGroupBox(tr("Exclusive Radio Buttons"));

  QRadioButton *radio1 = new QRadioButton(tr("&Radio button 1"));
  QRadioButton *radio2 = new QRadioButton(tr("R&adio button 2"));
  QRadioButton *radio3 = new QRadioButton(tr("Ra&dio button 3"));

  radio1->setChecked(true);

  list = new QComboBox();
  list->addItem("item 1");
  list->addItem("item 2");
  list->addItem("item 3");
  list->addItem("item 4");
  QVBoxLayout *vbox = new QVBoxLayout;
  vbox->addWidget(radio1);
  vbox->addWidget(radio2);
  vbox->addWidget(radio3);
  vbox->addWidget(list);
  vbox->addStretch(1);
  groupBox->setLayout(vbox);

  return groupBox;
}

QGroupBox *MyWindow::createSecondExclusiveGroup()
{
  QGroupBox *groupBox = new QGroupBox(tr("E&xclusive Radio Buttons"));
  groupBox->setCheckable(true);
  groupBox->setChecked(false);

  QRadioButton *radio1 = new QRadioButton(tr("Rad&io button 1"));
  QRadioButton *radio2 = new QRadioButton(tr("Radi&o button 2"));
  QRadioButton *radio3 = new QRadioButton(tr("Radio &button 3"));
  radio1->setChecked(true);
  QCheckBox *checkBox = new QCheckBox(tr("Ind&ependent checkbox"));
  checkBox->setChecked(true);

  QVBoxLayout *vbox = new QVBoxLayout;
  vbox->addWidget(radio1);
  vbox->addWidget(radio2);
  vbox->addWidget(radio3);
  vbox->addWidget(checkBox);
  vbox->addStretch(1);
  groupBox->setLayout(vbox);

  return groupBox;
}

QGroupBox *MyWindow::createNonExclusiveGroup()
{
  QGroupBox *groupBox = new QGroupBox(tr("Non-Exclusive Checkboxes"));
  groupBox->setFlat(true);

  QCheckBox *checkBox1 = new QCheckBox(tr("&Checkbox 1"));
  QCheckBox *checkBox2 = new QCheckBox(tr("C&heckbox 2"));
  checkBox2->setChecked(true);
  QCheckBox *tristateBox = new QCheckBox(tr("Tri-&state button"));
  tristateBox->setTristate(true);
  tristateBox->setCheckState(Qt::PartiallyChecked);

  QVBoxLayout *vbox = new QVBoxLayout;
  vbox->addWidget(checkBox1);
  vbox->addWidget(checkBox2);
  vbox->addWidget(tristateBox);
  vbox->addStretch(1);
  groupBox->setLayout(vbox);

  return groupBox;
}

QGroupBox *MyWindow::createPushButtonGroup()
{
  QGroupBox *groupBox = new QGroupBox(tr("&Push Buttons"));
  groupBox->setCheckable(true);
  groupBox->setChecked(true);

  pushButton = new QPushButton(tr("&Normal Button"));
  QPushButton *toggleButton = new QPushButton(tr("&Toggle Button"));
  toggleButton->setCheckable(true);
  toggleButton->setChecked(true);
  QPushButton *flatButton = new QPushButton(tr("&Flat Button"));
  flatButton->setFlat(true);

  QPushButton *popupButton = new QPushButton(tr("Pop&up Button"));
  QMenu *menu = new QMenu(this);
  menu->addAction(tr("&First Item"));
  menu->addAction(tr("&Second Item"));
  menu->addAction(tr("&Third Item"));
  menu->addAction(tr("F&ourth Item"));
  popupButton->setMenu(menu);

  QAction *newAction = menu->addAction(tr("Submenu"));
  QMenu *subMenu = new QMenu(tr("Popup Submenu"));
  subMenu->addAction(tr("Item 1"));
  subMenu->addAction(tr("Item 2"));
  subMenu->addAction(tr("Item 3"));
  newAction->setMenu(subMenu);

  QVBoxLayout *vbox = new QVBoxLayout;
  vbox->addWidget(pushButton);
  vbox->addWidget(toggleButton);
  vbox->addWidget(flatButton);
  vbox->addWidget(popupButton);
  vbox->addStretch(1);
  groupBox->setLayout(vbox);

  return groupBox;
}
